==> is-permutation-on-2.6.59.tgz: package/README.md <==
Checks if array has a permutation. [:running:] [:vhs:] [:package:] [:moon:]
> Alternatives: [compare], [map].<br>
> Similar: [permutation], [permutations], [isPermutation].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
array.isPermutationOn(x, y, [fn], [ths]);
// x:   an array
// y:   permutation?
// fn:  map function (v, i, x)
// ths: this argument
```

```javascript
const array = require('extra-array');

var x = [1, 2, 3, 4];
array.isPermutationOn(x, [4, 3, 2, 1]);
// true

array.isPermutationOn(x, [3, -1, -2, 4]);
// false

array.isPermutationOn(x, [3, -1, -2, 4], v => Math.abs(v));
// true
```

### references

- [Data.List.permutations(): Haskell](https://hackage.haskell.org/package/base-4.12.0.0/docs/Data-List.html#v:permutations)
- [List-Extra.isPermutationOf(): elm](https://package.elm-lang.org/packages/elm-community/list-extra/7.1.0/List-Extra#isPermutationOf)

[compare]: https://github.com/nodef/extra-array/wiki/isPermutation
[map]: https://github.com/nodef/extra-array/wiki/isPermutationOn
[:running:]: https://npm.runkit.com/@extra-array/is-permutation-on
[:package:]: https://www.npmjs.com/package/@extra-array/is-permutation-on
[:moon:]: https://www.npmjs.com/package/@extra-array/is-permutation-on.min
[:vhs:]: https://asciinema.org/a/319378
[permutation]: https://github.com/nodef/extra-array/wiki/permutation
[permutations]: https://github.com/nodef/extra-array/wiki/permutations
[isPermutation]: https://github.com/nodef/extra-array/wiki/isPermutation

==> is-permutation-on-2.7.6.tgz: package/README.md <==
Checks if array has a permutation. [:running:] [:vhs:] [:package:] [:moon:]
> Alternatives: [compare], [map].<br>
> Similar: [permutation], [permutations], [isPermutation].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
array.isPermutationOn(x, y, [fn], [ths]);
// x:   an array
// y:   permutation?
// fn:  map function (v, i, x)
// ths: this argument
```

```javascript
const array = require('extra-array');

var x = [1, 2, 3, 4];
array.isPermutationOn(x, [4, 3, 2, 1]);
// true

array.isPermutationOn(x, [3, -1, -2, 4]);
// false

array.isPermutationOn(x, [3, -1, -2, 4], v => Math.abs(v));
// true
```

### references

- [Data.List.permutations: Haskell](https://hackage.haskell.org/package/base-4.12.0.0/docs/Data-List.html#v:permutations)
- [List-Extra.isPermutationOf: elm](https://package.elm-lang.org/packages/elm-community/list-extra/7.1.0/List-Extra#isPermutationOf)

[compare]: https://github.com/nodef/extra-array/wiki/isPermutation
[map]: https://github.com/nodef/extra-array/wiki/isPermutationOn
[:running:]: https://npm.runkit.com/@extra-array/is-permutation-on
[:package:]: https://www.npmjs.com/package/@extra-array/is-permutation-on
[:moon:]: https://www.npmjs.com/package/@extra-array/is-permutation-on.min
[:vhs:]: https://asciinema.org/a/319378
[permutation]: https://github.com/nodef/extra-array/wiki/permutation
[permutations]: https://github.com/nodef/extra-array/wiki/permutations
[isPermutation]: https://github.com/nodef/extra-array/wiki/isPermutation
